/* basic.c
 *
 * Copyright 2018 Bruce Cowan <bruce@bcowan.me.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

//#include <stdio.h>
//#include <stdlib.h>
//#include <string.h>

#include <glib.h>

#include "array.h"

typedef struct
{
    Array *array;
} ArrayFixture;

static void
create_array (ArrayFixture  *fixture,
              gconstpointer  user_data)
{
    size_t length = GPOINTER_TO_SIZE (user_data);
    fixture->array = array_new (g_free);

    for (size_t i = 0; i < length; i++)
    {
        gchar *str = g_strdup_printf ("String #%zu", i);
        array_add (fixture->array, str);
    }
}

static void
test_get (ArrayFixture *fixture,
          gconstpointer user_data)
{
    size_t length = GPOINTER_TO_SIZE (user_data);

    for (size_t i = 0; i < length; i++)
    {
        const gchar *element = (const gchar *) array_get (fixture->array, i);
        g_autofree gchar *compare = g_strdup_printf ("String #%zu", i);
        g_assert_cmpstr (element, ==, compare);
    }
}

static void
destroy_array (ArrayFixture *fixture,
               gconstpointer user_data)
{
    g_clear_pointer (&fixture->array, array_unref);
}

int
main (int    argc,
      char **argv)
{
    g_test_init (&argc, &argv, NULL);

    g_test_add ("/array/get", ArrayFixture, GSIZE_TO_POINTER (100),
                create_array, test_get, destroy_array);

    return g_test_run ();
}
